require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xsqlhagroup',
  dscmeta_resource_friendly_name: 'xSqlHAGroup',
  dscmeta_resource_name: 'MSFT_xSqlHAGroup',
  dscmeta_module_name: 'xSqlPs',
  dscmeta_module_version: '1.4.0.0',
  docs: 'The DSC xSqlHAGroup resource type.
         Automatically generated from version 1.4.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of sql availability group',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_endpointname: {
      type: 'String',
      desc: 'Name of EndPoint to access High Availability sql instance.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'Name of sql instance',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clustername: {
      type: 'String',
      desc: 'The name of windows failover cluster for the availability group',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqladministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Sql sa credential.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domaincredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Domain credential could get list of cluster nodes.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_databasebackuppath: {
      type: 'String',
      desc: 'The net share for Sql replication initialization',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_database: {
      type: 'Array[String]',
      desc: 'Array of databases on the local sql instance. Each database can belong to only one HA group.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
