require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xsqlserverinstall',
  dscmeta_resource_friendly_name: 'xSqlServerInstall',
  dscmeta_resource_name: 'MSFT_xSqlServerInstall',
  dscmeta_module_name: 'xSqlPs',
  dscmeta_module_version: '1.4.0.0',
  docs: 'The DSC xSqlServerInstall resource type.
         Automatically generated from version 1.4.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sqluserdbdir: {
      type: 'Optional[String]',
      desc: 'Specify the directory for UserDB data files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_updateenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specify whether SQL server setup should discover and include product updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_svcaccount: {
      type: 'Optional[String]',
      desc: 'Specify the startup account for the SQL server service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_versionid: {
      type: 'Optional[String]',
      desc: 'The numeric version identifier for the instance to be installed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_agentsvcaccount: {
      type: 'Optional[String]',
      desc: 'Specify the account for SQL server agent service.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sourcepath: {
      type: 'String',
      desc: 'The share path of sql server software.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlbackupdir: {
      type: 'Optional[String]',
      desc: 'Specify the directory for backup files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqladministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Sql sa credential',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'The name of sql instance.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcepathcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The credential that vm could use to access net share of sql server software.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sqluserdblogdir: {
      type: 'Optional[String]',
      desc: 'Specify the directory for UserDB log files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqltempdbdir: {
      type: 'Optional[String]',
      desc: 'Specify the directory for TempDB files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlcollation: {
      type: 'Optional[String]',
      desc: 'Specify the default collation for SQL server',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_features: {
      type: 'Optional[String]',
      desc: 'List of names of Sql Server features to install',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sysadminaccounts: {
      type: 'Optional[String]',
      desc: 'Specify logins to be members of the sysadmin role.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installsqldatadir: {
      type: 'Optional[String]',
      desc: 'Specify the directory for SQL server system db files',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
