require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xwaitforsqlhagroup',
  dscmeta_resource_friendly_name: 'xWaitForSqlHAGroup',
  dscmeta_resource_name: 'MSFT_xWaitForSqlHAGroup',
  dscmeta_module_name: 'xSqlPs',
  dscmeta_module_version: '1.4.0.0',
  docs: 'The DSC xWaitForSqlHAGroup resource type.
         Automatically generated from version 1.4.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_clustername: {
      type: 'String',
      desc: 'The name of windows failover cluster for the availability group.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sqladministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Sql sa credential',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'The name of sql instance.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of retries to check HA group existency',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of Sql High Availability group',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retryintervalsec: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Interval to check the HA group existency',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_domaincredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Domain credential could get list of cluster nodes.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
